@@ -47,7 +47,7 @@ if (! -r "test$TestN.files") {
 	exit 8;
 	}
 print "run-basic-dotest.pl: Starting built-in test $TestN" if ($debug >= 1);
-$abinis = &transpath("../../../src/main/abinis$XSUFX");
+$abinis = &transpath("../../../src/98_main/abinis$XSUFX");
 $timeout_cmd = &transpath("../../../src/nightly/timeout$XSUFX");
 if ($SUFXstyle eq 'vms') {
   $cmd = "pipe run [-]abinis < test$TestN.files > test$TestN.log";
