@@ -21,17 +21,18 @@ $\ = "\n";              # set output record separator
 #
 $DELAY = 2;		# delay in seconds between 2 verifications of the STATUS file
 $MAXLOOP = '50';	# maximum count for STATUS file checking loop
-%PspFiles=('1','01h.pspgth',
-	 '2','14si.pspgth',
-	 '3','01h.pspgth:04be.pspgth',
-	 '4','70yb.pspnc',
-	 '5','13al.pspgth',
-	 '6','14si.xml');
+%PspFiles=('in_1','01h.pspgth',
+	 'in_2','70yb.pspnc',
+	 'in_3','01h.pspgth:04be.pspgth',
+	 'in_bigdft','01h.pspgth',
+	 'in_etsf_io','20ca.paw',
+	 'in_libxc','83bi.psphgh',
+	 'in_wannier90','31ga.pspnc:33as.pspnc');
 #
 $debug = 0;		# Debug level ???
 if ($ARGV[1] eq '') {
   print 'Missing argument';
-	print "Usage is: run-basic-tests machine_name [ 1 | 2 | 3 | 4 | 5 | 6] srcDir";
+	print "Usage is: run-basic-tests machine_name [ in_1 | in_2 | in_3 | in_bigdft | in_etsf_io | in_libxc | in_wannier90 ] srcDir";
 	exit 16;
 	}
 $MACH = $ARGV[0];
@@ -150,7 +151,7 @@ print "$OStype $SLASH $SUFXstyle $inputfile" if ($debug >=2);
 if (! -e &transpath("$inputfile") ) {
 	print "Invalid test number: $TestN";
 	print "Expected input file $inputfile not found";
-	print "Usage is: run-basic-tests machine_name [ 1 | 2 | 3 | 4 | 5 | 6 ] srcDir ";
+	print "Usage is: run-basic-tests machine_name [ in_1 | in_2 | in_3 | in_bigdft | in_etsf_io | in_libxc | in_wannier90 ] srcDir ";
 	exit (8);
 	}
 #
@@ -191,8 +192,12 @@ else {
   $statfile = "test$TestN".'_STATUS';	# name of STATUS file
   }
 unlink($statfile) if (-e $statfile);
-# Write abinit.files for test
+# Write input files for test
 system("$COPY_COMMAND ".&transpath("$srcDir/tests/built-in/Input/test$TestN.in")." test$TestN.in");
+if ($TestN eq 'in_wannier90') {
+  system("$COPY_COMMAND ".&transpath("$srcDir/tests/built-in/Input/testin_wannier90o_w90.win")." testin_wannier90o_w90.win");
+  }
+# Write abinit.files for test
 $rc = open (FILES,">test$TestN.files");
 print FILES "test$TestN.in";
 print FILES "test$TestN.out";
