@@ -40,6 +40,7 @@ my_output="${abinit_outdir}/${test_dir}/${my_string}/test${test_number}"
 rm -f "${my_output}.in" "${my_output}.out" "${my_output}.log"
 rm -f "${my_output}i_*" "${my_output}o_*" "${my_output}_*"
 cp "${abinit_inpdir}/${test_dir}/Input/test${test_number}.in" "${my_output}.in"
+cp "${abinit_inpdir}/${test_dir}/Input/testin_wannier90o_w90.win" "${my_dir}/testin_wannier90o_w90.win"
 
 # Write abinit.files for test
 cat > "${my_output}.files" <<EOF
@@ -52,29 +53,34 @@ EOF
 
 case "${test_number}" in
 
- 1)
+ in_1)
   echo "${abinit_pspdir}/01h.pspgth" >> "${my_output}.files"
   ;;
 
- 2)
-  echo "${abinit_pspdir}/14si.pspgth" >> "${my_output}.files"
+ in_2)
+  echo "${abinit_pspdir}/70yb.pspnc" >> "${my_output}.files"
   ;;
 
- 3)
+ in_3)
   echo "${abinit_pspdir}/01h.pspgth" >> "${my_output}.files"
   echo "${abinit_pspdir}/04be.pspgth" >> "${my_output}.files"
   ;;
 
- 4)
-  echo "${abinit_pspdir}/70yb.pspnc" >> "${my_output}.files"
+ in_bigdft)
+  echo "${abinit_pspdir}/01h.pspgth" >> "${my_output}.files"
   ;;
 
- 5)
-  echo "${abinit_pspdir}/13al.pspgth" >> "${my_output}.files"
+ in_etsf_io)
+  echo "${abinit_pspdir}/20ca.paw" >> "${my_output}.files"
   ;;
 
- 6)
-  echo "${abinit_pspdir}/14si.xml" >> "${my_output}.files"
+ in_libxc)
+  echo "${abinit_pspdir}/83bi.psphgh" >> "${my_output}.files"
+  ;;
+
+ in_wannier90)
+  echo "${abinit_pspdir}/31ga.pspnc" >> "${my_output}.files"
+  echo "${abinit_pspdir}/33as.pspnc" >> "${my_output}.files"
   ;;
 
  *)
