@@ -44,7 +44,7 @@ $PERL = $ENV{'PERL'};
 $, = ' ';               # set output field separator
 $\ = "\n";              # set output record separator
 #
-@MachList=('t3e','sgi','tux','vpp','hp','compaq_es40','ibm_44p','sr8k','mpd','sun','dummy','test','spinoza','fock','max','chpit','lemaitre','sleepy(-compilo)','pwrg4','mpich2','generic','chum(-compilo)', 'cea', 'bigmac','green');
+@MachList=('t3e','sgi','tux','vpp','hp','compaq_es40','ibm_44p','sr8k','mpd','sun','dummy','test','spinoza','fock','max','lemaitre','sleepy(-compilo)','pwrg4','mpich2','generic','chum(-compilo)', 'cea', 'bigmac','green','chpit-intel11','chpit-gcc44');
 @CompiloList = ('g95','pgi','gcc41','gcc42','gcc43','pathscale','intel','intel10','open64','sun');
 @Cases = ('0','1','2','4','10');
 $debug = 2;
@@ -323,12 +323,6 @@ elsif ($MACH eq 'compaq_es40') {
   $CASE10 = 0;
 	}
 #-----------------------------------
-# For the HP integrity Itanium 4 processor in LLN
-elsif ($MACH eq 'chpit') {
-  $MPIRUN_NP = ' /usr/local/mpich/bin/mpirun -np';
-  $CASE10 = 0;
-        }
-#-----------------------------------
 # For the Sun V20 Opteron-based machine in LLN
 elsif ($MACH eq 'lemaitre') {
   $MPIRUN_NP = '/usr/local/mpich-1.2.6-eth-intel9.1/bin/mpirun -np';
@@ -494,6 +488,22 @@ print "The $MPICH_DIR will be used...($OPENMPI)";
         close (FILE);
 }
 #-----------------------------------
+# For the HP integrity Itanium 4 processor in LLN
+elsif ($MACH eq 'chpit-gcc44') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi-gcc44/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the HP integrity Itanium 4 processor in LLN
+elsif ($MACH eq 'chpit-intel11') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
 # For the MacBookPRo with Intel 2 cores "pwrg4"
 elsif ($MACH eq 'pwrg4') {
   $MPICH = 1;
@@ -517,13 +527,14 @@ elsif ($MACH eq 'pwrg4') {
 #-----------------------------------
 # For the cluster of PowerPC Mac OS X "max" with biprocs
 elsif ($MACH eq 'max') {
-  $MPICH = 1;
-  $MPICH_DIR = '/usr/local/mpich-1.2.7/bin';
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/usr/local/openmpi-g95/bin';
   $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
   $MACH0='max';
   $MACH1='max';
-  $MACH2='maxi8';
-  $MACH3='maxi8';
+  $MACH2='max';
+  $MACH3='max';
   $CASE10 = 0;
   unlink 'cluster1','cluster2','cluster4';
         open (FILE,">cluster1") || die "Unable to open FILE cluster1";
