@@ -22,10 +22,10 @@
 # The top_testdir must be an absolute path.
 #
 # For example, under unix C-shell, on the machine fock :
-#  run-standard-tests fock ../src/main /home/me/abinit/test fast  >& log_file        run all tests in fast on hilbert
-#  run-standard-tests hilbert ../src/main /home/me/abinit/test v1 1  >& log_file        run only test 1 in v1 on hilbert
-#  run-standard-tests hilbert ../src/main /home/me/abinit/test v2 3 end  >& log_file    run tests from case_3 to the end in v2 on hilbert
-#  run-standard-tests hilbert ../src/main /home/me/abinit/test tutorial 8 22  >& log_file    run tutorial tests between 8 and 22 included.
+#  run-standard-tests fock ../src/98_main /home/me/abinit/test fast  >& log_file        run all tests in fast on hilbert
+#  run-standard-tests hilbert ../src/98_main /home/me/abinit/test v1 1  >& log_file        run only test 1 in v1 on hilbert
+#  run-standard-tests hilbert ../src/98_main /home/me/abinit/test v2 3 end  >& log_file    run tests from case_3 to the end in v2 on hilbert
+#  run-standard-tests hilbert ../src/98_main /home/me/abinit/test tutorial 8 22  >& log_file    run tutorial tests between 8 and 22 included.
 #
 
 $abinit_cmdpar = $ENV{'abinit_cmdpar'};
@@ -42,7 +42,7 @@ $timeout = '0' if ($timeout eq '');
 
 $, = ' ';               # set output field separator
 $\ = "\n";              # set output record separator
-@Series = ('fast','v1','v2','v3','v4','v5','physics','cpu','tutorial','tutorespfn','etsf_io','etsf_xc','bigdft','wannier90');
+@Series = ('fast','v1','v2','v3','v4','v5','physics','cpu','tutorial','tutorespfn','etsf_io','libxc','bigdft','wannier90','abirules','gwdp');
 $TestDir = '.';		# default is current directory
 # abinis processing options:
 $optKeepfn4 = 1;	# keep files fn4* after test completion
@@ -66,10 +66,13 @@ if ($ARGV[0] eq '') {
   exit 16;
   }
 $MACH = $ARGV[0];
+print "Machine $MACH"  ;
 $abinit_bindir = $ARGV[1];
+print "Bindir $abinit_bindir"  ;
 # I know, the following is ugly! (YP)
 $abinit_nightlydir = "$abinit_bindir/../nightly";
 $top_testdir = $ARGV[2];
+print "Top_testdir  $top_testdir"  ;
 $argptr = 3;
 # check first argument against some tests serie
 foreach $serie (@Series) {
@@ -79,6 +82,7 @@ foreach $serie (@Series) {
 		last;
 		}
 	}
+print "Testdir  $TestDir"  ;
 # set default first and last test number
 $FIRST = 'first';
 $LAST = 'end';
@@ -314,8 +318,10 @@ $CODE_LWF = &perlpath("$abinit_bindir/lwf$XSUFX");	# codename for lwf
 $CODE_LWF = "$timeout_cmd$CODE_LWF";
 $CODE_BAND2EPS = &perlpath("$abinit_bindir/band2eps$XSUFX");	# codename for band2eps
 $CODE_BAND2EPS = "$timeout_cmd$CODE_BAND2EPS";
+$CODE_DOCCHK = &perlpath("$top_testdir/Scripts/docchk.py$XSUFX");    # codename for band2eps
+$CODE_DOCCHK = "$timeout_cmd$CODE_DOCCHK";
 #$CODE_PAR = &perlpath("$abinit_cmdpar");	# codename for parallel version WARNING XG051130 DOES NOT WORK
-$CODE_PAR = '/usr/local/mpi-pgi4/bin/mpirun -np 2 -machinefile sleepy.pcpm.ucl.ac.be:2 ../../../src/main/abinip' ;      # run parallel version on sleepy
+$CODE_PAR = '/usr/local/mpi-pgi4/bin/mpirun -np 2 -machinefile sleepy.pcpm.ucl.ac.be:2 ../../../src/98_main/abinip' ;      # run parallel version on sleepy
 $CODE_PAR = "$timeout_cmd$CODE_PAR";
 
 $INPUTDIR = &transpath("$top_testdir/$TestDir/Input");		# input directory
@@ -416,6 +422,9 @@ while (<CONF>) {
 	elsif ($prgcmd eq 'lwf') {
 		&dolwftest($CurTest,$P1,$P2,$P3,$P4,$P5);
 		}
+        elsif ($prgcmd eq 'docchk') {
+                &dodocchk($CurTest);
+                }
 	elsif ($prgcmd eq 'band2eps') {
 		&doband2epstest($CurTest,$P1,$P2,$P3,$P4,$P5);
 		}
@@ -956,11 +965,18 @@ sub doanatest {
 	else {
 		system ("$CODE_ANADDB < $RUNfile > $logfn $REDIRECT_ERR");
 		}
-# Compare with reference files
+# Compare with reference output file
 	$REFoutfn = &transpath("$REF/$fn2");
 	print "Finished anaddb, comparing $outfn with $REFoutfn";
 	system ("$DIFF_COMMAND $outfn $REFoutfn > $difffn");
 	&dofldiff("Case_$TID","$fn2","$REF/$fn2",$fldopt);	# compare floating point numbers
+# Compare with reference log file
+        if("$TestDir/$TID" eq 'v5/28') {
+        $REFlogfn = &transpath("$REF/$logfn");
+        print "Finished anaddb, comparing $logfn with $REFlogfn";
+        system ("$DIFF_COMMAND $logfn $REFlogfn > 'diff.t28.log'");
+        &dofldiff("Case_$TID.log","$logfn","$REF/$logfn",$fldopt);      # compare floating point numbers
+              }
 # check for work file to be deleted
 	system("$ERASE_COMMAND $fntodelete") if ($fntodelete ne '');	# delete file
 	return;			# go read next line from configuration file
@@ -1524,6 +1540,53 @@ sub dolwftest {
 	return;                 # go read next line from configuration file
 	}
 # ****************************************
+sub dodocchk {
+        local($TID) = @_;
+#
+# purpose: check the documentation
+# arguments:
+#               $TID = test identification (1 to 3 characters string) that will be used as suffix to diff
+# and prefix to log file names
+#               $p1,..$p5 = 1 to 5 parameters [re]defining some option or the file names (fn1 to fn4) that
+# will be put into the "files" file named "band2eps.run";
+# the parameter format for a file name is: fnI=path
+# the parameter format for an option is: opt=option ; see setfnopt
+#       $fn1 = input to band2eps
+#       $fn2 = output file (eps) name that will be compared with reference.
+#       $fn3 = _freq file
+#       $fn4 = _displ file
+# set default files names derived from $TID:
+        $fn1 = "t$TID.out";                 # t51.out
+        $fn2 = "t$TID.log";                 # t51.log
+        print "Case_$TID:";
+# Nothing done in case 'MACH' is set to chkinabi
+        if ($MACH eq 'chkinabi') {
+                return ;
+                }
+# Remove existing files related to this test case:
+        $outfn = &transpath($fn1);
+        $logfn = &transpath($fn2);
+        $difffn = "diff.t$TID";      # diff.t51
+        unlink($RUNfile,$outfn,$logfn,$difffn);
+# Run the test case
+        print "Starting docchk";
+        if ($OStype eq 'MacOS') {
+                system ("$CODE_DOCCHK \xb7 $logfn ");
+                }
+        else {
+		print "$CODE_DOCCHK > $logfn $REDIRECT_ERR" ;
+                system ("$CODE_DOCCHK > $logfn $REDIRECT_ERR");
+                }
+        system ("grep -v SUCCESS $logfn > $outfn");
+# Compare with reference files
+        $REFfn = &transpath("$REF/$fn1");
+        print "Finished docchk, comparing $outfn with $REFfn";
+        system ("$DIFF_COMMAND $outfn $REFfn > $difffn");
+        &dofldiff("Case_$TID","$fn1","$REF/$fn1",$fldopt);  # compare floating point numbers
+        return;                 # go read next line from configuration file
+        }
+
+# ****************************************
 sub doband2epstest {
 	local($TID,$p1,$p2,$p3,$p4,$p5) = @_;
 #
