@@ -128,7 +128,7 @@ graph.worldymax = float()
 
 #feedback variables
 feedback = VariableContainer()
-feedback.feedback = True
+feedback.feedback = False
 feedback.filename = '.%s_feedback' %program[:-3]
 feedback.ntimeused = int()
 feedback.email = 'benjamin.tardif@umontreal.ca'
